@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 2001-2024 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 2001-2025 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -21,14 +21,16 @@ MALLOC_DEFINE(M_NVIDIA, "nvidia", "NVIDIA memory allocations");
 TASKQUEUE_DEFINE_THREAD(nvidia);
 NvBool os_is_unload_flush_ongoing = NV_FALSE;
 
-NvU32 os_page_size  = PAGE_SIZE;
-NvU64 os_page_mask  = ~PAGE_MASK;
-NvU8  os_page_shift = PAGE_SHIFT;
+NvU64 os_page_size     = PAGE_SIZE;
+NvU64 os_max_page_size = PAGE_SIZE;
+NvU64 os_page_mask     = ~PAGE_MASK;
+NvU8  os_page_shift    = PAGE_SHIFT;
 
 NvBool os_cc_enabled = 0;
 NvBool os_cc_sev_snp_enabled = 0;
 NvBool os_cc_snp_vtom_enabled = 0;
 NvBool os_cc_tdx_enabled = 0;
+NvBool os_cc_sme_enabled = 0;
 
 NvBool os_dma_buf_enabled = NV_FALSE;
 
@@ -141,7 +143,7 @@ NV_STATUS NV_API_CALL os_get_current_thread(NvU64 *threadId)
     return NV_OK;
 }
 
-NV_STATUS NV_API_CALL os_get_current_time(
+NV_STATUS NV_API_CALL os_get_system_time(
     NvU32 *sec,
     NvU32 *usec
 )
@@ -165,26 +167,26 @@ NV_STATUS NV_API_CALL os_get_current_time(
 // less precise result and is faster than nanouptime().
 // Using nanouptime() for higher precision */
 //
-NvU64 NV_API_CALL os_get_current_tick_hr(void)
+NvU64 NV_API_CALL os_get_monotonic_time_ns_hr(void)
 {
     struct timespec ts;
     nanouptime(&ts);
     return ((NvU64)ts.tv_sec * NSEC_PER_SEC + (NvU64)ts.tv_nsec);
 }
 
-NvU64 NV_API_CALL os_get_current_tick(void)
+NvU64 NV_API_CALL os_get_monotonic_time_ns(void)
 {
     NvU32 sec, usec;
 
     /* TODO: can we use getnanouptime() for this? */
-    (void) os_get_current_time(&sec, &usec);
+    (void) os_get_system_time(&sec, &usec);
 
     return ((NvU64)sec * NANOSECOND + (NvU64)usec * NANOSECOND_PER_USEC);
 }
 
-NvU64 NV_API_CALL os_get_tick_resolution(void)
+NvU64 NV_API_CALL os_get_monotonic_tick_resolution_ns(void)
 {
-    /* Currently using os_get_current_time() which has microsecond resolution */
+    /* Currently using os_get_system_time() which has microsecond resolution */
     return NANOSECOND_PER_USEC;
 }
 
